
#define MOTOR_PIN 9
#define SWITCH_PIN 2
#define SPEED_CONTROL_PIN A5
#define LED_PIN 13

int led_state = LOW; // This variable remembers the LED state (on or off)

unsigned long next_led_toggle_time = 1000; // This is the next time the LED should toggle (in milliseconds)

void toggleLED()
{
    /* This is a FUNCTION called toggleLED.
    When it is CALLED by the code in loop, it
    runs once from top to bottom */
    
    if (led_state == HIGH)
    {
        led_state = LOW; // The lED is currently ON, so turn it OFF.
    }
    else
    {
        led_state = HIGH;  // The lED is currently OFF, so turn it ON.
    }
    
    digitalWrite(LED_PIN, led_state);
}

void setup()
{
    pinMode(MOTOR_PIN, OUTPUT);
    pinMode(LED_PIN, OUTPUT);
    pinMode(SWITCH_PIN, INPUT_PULLUP);
    pinMode(SPEED_CONTROL_PIN, INPUT);
}

void loop()
{
    /* Notice how this code has NO delays in it!
    We still get the LED toggling slowly and the motor
    updating fast, just how we want it. */
    
    int value = analogRead(SPEED_CONTROL_PIN);
    analogWrite(MOTOR_PIN, value / 4);
    
    /* The millis() function returns the number of milliseconds
    since the Arduino was turned on */
    unsigned long time_now = millis();
    
    if (time_now > next_led_toggle_time)
    {
        next_led_toggle_time += 1000; // Toggle again in another 1000ms
        toggleLED(); // CALL the toggleLED function that actually does the work
    }
}
